@@ -16,24 +16,27 @@ Re class in L<SPVM> has methods for more Perlish regular expression.
 
   use Re;
   
+  # Match
   my $string = "Hello World"
   my $match = Re->m($string, "^Hellow");
   
-  # ABC de ABC
-  my $string_ref = ["abc de abc"];
-  Re->s($string_ref, ["abc", "g"], "ABC");
+  # Replace
+  my $string = "abc de abc";
+  my $replace_info = Re->s(my $_ = [$string], ["abc", "g"], "ABC");
+  $string = $_->[0];
   
+  # Split
   my $parts = Re->split(" +", $string);
 
 =head1 Class Methods
 
 =head2 m
 
-C<static method m : L<Regex::Match|SPVM::Regex::Match> ($string_or_buffer : object of string|L<StringBuffer|SPVM::StringBuffer>, $pattern_and_flags : object of string|string[], $offset_ref : int* = undef, $length : int = -1);>
+C<static method m : L<Regex::Match|SPVM::Regex::Match> ($string_value : string|L<StringBuffer|SPVM::StringBuffer>, $pattern_and_flags : string|string[], $offset_ref : int* = undef, $length : int = -1);>
 
 Calls L<Regex#new|SPVM::Regex/"new"> method given $pattern_and_flags. $pattern_and_flags is a pattern string or a string array that contains a pattern and flags.
 
-And the returned L<Regex|SPVM::Regex> object calls L<Regex#match|SPVM::Regex/"match"> method given $string_or_buffer, $offset_ref, $offset_ref, $length, and returns its return value.
+And the returned L<Regex|SPVM::Regex> object calls L<Regex#match|SPVM::Regex/"match"> method given $string_value, $offset_ref, $offset_ref, $length, and returns its return value.
 
 The L<Regex|SPVM::Regex> object is cached.
 
@@ -43,11 +46,11 @@ Exceptions thrown by L<Regex#new|SPVM::Regex/"new"> method and L<Regex#match|SPV
 
 =head2 s
 
-C<static method s : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_or_buffer : object of string[]|L<StringBuffer|SPVM::StringBuffer>, $pattern_and_flags : object of string|string[], $replace : object of string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1);>
+C<static method s : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_value : string[]|L<StringBuffer|SPVM::StringBuffer>, $pattern_and_flags : string|string[], $replace : string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1);>
 
 Calls L<Regex#new|SPVM::Regex/"new"> method given $pattern_and_flags. $pattern_and_flags is a pattern string or a string array that contains a pattern and flags.
 
-And the returned L<Regex|SPVM::Regex> object calls L<Regex#replace|SPVM::Regex/"replace"> method given $string_ref_or_buffer, $offset_ref, $offset_ref, $length, and returns its return value.
+And the returned L<Regex|SPVM::Regex> object calls L<Regex#replace|SPVM::Regex/"replace"> method given $string_ref_value, $offset_ref, $offset_ref, $length, and returns its return value.
 
 The flags in $pattern_and_flags can contains C<"g"> to L<Regex#replace_g|SPVM::Regex/"replace_g"> method instead of L<Regex#replace|SPVM::Regex/"replace"> method.
 
@@ -59,7 +62,7 @@ Exceptions thrown by L<Regex#new|SPVM::Regex/"replace"> method and L<Regex#match
 
 =head2 split
 
-C<static method split : string[] ($pattern_and_flags : object of string|string[], $string : string, $limit : int = 0)>
+C<static method split : string[] ($pattern_and_flags : string|string[], $string : string, $limit : int = 0)>
 
 Calls L<Regex#new|SPVM::Regex/"new"> method given $pattern_and_flags. $pattern_and_flags is a pattern string or a string array that contains a pattern and flags.
 
