@@ -1,6 +1,6 @@
 package SPVM::Regex;
 
-our $VERSION = "0.248";
+our $VERSION = "0.249";
 
 1;
 
@@ -22,12 +22,17 @@ B<Re:>
 
   use Re;
   
+  # Match
   my $string = "Hello World"
   my $match = Re->m($string, "^Hellow");
   
-  # ABC de ABC
-  my $string_ref = ["abc de abc"];
-  Re->s($string_ref, ["abc", "g"], "ABC");
+  # Replace
+  my $string = "abc de abc";
+  my $replace_info = Re->s(my $_ = [$string], ["abc", "g"], "ABC");
+  $string = $_->[0];
+  
+  # Split
+  my $parts = Re->split(" +", $string);
 
 B<Regex:>
 
@@ -129,7 +134,7 @@ B<Regex:>
 
 =head1 Details
 
-=head1 Regular Expression Syntax
+=head2 Regular Expression Syntax
 
 See L<Google RE2 Syntax|https://github.com/google/re2/wiki/Syntax> about the syntax of regular expressions.
 
@@ -141,7 +146,7 @@ Use L<Re|SPVM::Re> class if you want to use more Perlish pattern match and repla
 
 =head2 new
 
-C<static method new : Regex ($pattern : string, $flags : string = undef);>
+C<static method new : L<Regex|SPVM::Regex> ($pattern : string, $flags : string = undef);>
 
 Creates a new L<Regex|SPVM::Regex> object and compiles the regex pattern $pattern with the flags $flags, and retruns the new object.
 
@@ -160,35 +165,35 @@ Examples:
 
 =head2 match
 
-C<method match : L<Regex::Match|SPVM::Regex::Match> ($string_or_buffer : object of string|L<StringBuffer|SPVM::StringBuffer>, $offset_ref : int* = undef, $length : int = -1);>
+C<method match : L<Regex::Match|SPVM::Regex::Match> ($string_value : string|L<StringBuffer|SPVM::StringBuffer>, $offset_ref : int* = undef, $length : int = -1);>
 
-Performs a pattern match on the string or the StringBuffer object $string_or_buffer from the offset $$offset_ref to the length $length.
+Performs a pattern match on the string or the StringBuffer object $string_value from the offset $$offset_ref to the length $length.
 
 If the pattern match succeeds, return a new L<Regex::Match|SPVM::Regex::Match> object, otherwise returns undef.
 
 $$offset_ref is updated to the next position if it is specified.
 
-If $length is less than 0, it is set to the length of $string_or_buffer.
+If $length is less than 0, it is set to the length of $string_value.
 
 Exceptions:
 
-$string_or_buffer must be defined. Otherwise an exception is thrown.
+$string_value must be defined. Otherwise an exception is thrown.
 
-The type of $string_ref_or_buffer must be string or StringBuffer. Otherwise an exception is thrown.
+The type of $string_ref_value must be string or StringBuffer. Otherwise an exception is thrown.
 
-$$offset_ref + $length must be less than or equal to the length of $string_or_buffer. Otherwise an exception is thrown.
+$$offset_ref + $length must be less than or equal to the length of $string_value. Otherwise an exception is thrown.
 
 =head2 replace
 
-C<method replace : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_or_buffer : object of string[]|L<StringBuffer|SPVM::StringBuffer>, $replace : object of string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1, $options : object[] = undef);>
+C<method replace : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_value : string[]|L<StringBuffer|SPVM::StringBuffer>, $replace : string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1, $options : object[] = undef);>
 
-The string to be replaced is either $string_ref_or_buffer->[0] when the type is string or $string_ref_or_buffer when the type is StringBuffer.
+The string to be replaced is either $string_ref_value->[0] when the type is string or $string_ref_value when the type is StringBuffer.
 
 Replaces the string from the offset $$offset_ref to the length $length with the replacement string or the callback $replace with the options $options using a regular expression.
 
 $$offset_ref is updated to the next position if it is specified.
 
-If $length is less than 0, it is set to the length of $string_or_buffer.
+If $length is less than 0, it is set to the length of $string_value.
 
 If the replacement succeeds, returns a new L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo>, otherwise retunrs undef.
 
@@ -196,7 +201,7 @@ Options:
 
 =over 2
 
-=item * C<global>
+=item * C<global> : Int = 0
 
 This option must be a L<Int|SPVM::Int> object. Otherwise an exception is thrown.
 
@@ -206,21 +211,21 @@ If the value of the L<Int|SPVM::Int> object is a true value, the global replacem
 
 Exceptions:
 
-$string_ref_or_buffer must be defined. Otherwise an exception is thrown.
+$string_ref_value must be defined. Otherwise an exception is thrown.
 
-The type of $string_ref_or_buffer must be string or StringBuffer. Otherwise an exception is thrown.
+The type of $string_ref_value must be string or StringBuffer. Otherwise an exception is thrown.
 
 $replace must be a string or a L<Regex::Replacer|SPVM::Regex::Replacer> object. Otherwise an exception is thrown.
 
 $$offset_ref must be greater than or equal to 0. Otherwise an exception is thrown.
 
-$$offset_ref + $length must be less than or equal to the length of $string_ref_or_buffer. Otherwise an exception is thrown.
+$$offset_ref + $length must be less than or equal to the length of $string_ref_value. Otherwise an exception is thrown.
 
 Exceptions of the L<match_forward|/"match_forward"> method can be thrown.
 
 =head2 replace_g
 
-C<method replace_g  : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_or_buffer : object of string[]|L<StringBuffer|SPVM::StringBuffer>, $replace : object of string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1, $options : object[] = undef):>
+C<method replace_g  : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_value : string[]|L<StringBuffer|SPVM::StringBuffer>, $replace : string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1, $options : object[] = undef):>
 
 Calls L</replace> method given the same arguments but with C<global> option set to 1, and returns its return value.
 
